# DABench Task 506 - 1. What is the average number of reviews per hotel in the dataset?

## Task Description

1. What is the average number of reviews per hotel in the dataset?

## Concepts

Summary Statistics

## Data Description

Dataset file: `hotel_data.csv`

The data is available in the `train.csv` file in the public directory.

## Constraints

Calculate the mean reviews per hotel from the entire dataset. Round your result to two decimal places.

## Files

- `train.csv` - The training data
- `sample_submission.csv` - A sample submission file in the correct format

## Submission Format

Submit a CSV with columns `id,answer`, containing one row. In the `answer` cell include:
@average_reviews[average]

"average" is a number rounded to two decimal places representing the average number of reviews per hotel.

## Evaluation

Submissions are evaluated on **exact match** with the ground truth answer (with tolerance of 0.01 for floating-point values).

## Goal

Provide the correct answer in the specified format.

## Difficulty Level

Easy
